.. default-role:: code

Title1
======
I\_nt\_r\`o. pintro `line 9 <thonny://C:\\users\\aivar\\Desktop\\punktid.py>`__

Intro. pintro `line 9 <thonny://C:\\users\\aivar\\Desktop\\punktid.py#22>`__

\.. Intro. pintro `line 9 <thonny://C:\\users\\aivar\\Desktop\\fstrings.py#3:3>`__

The |biohazard| symbol must be used on containers used to
dispose of medical waste.

.. |biohazard| image:: stop

.. topic:: Line 1 name `undefined`.
	:class: toggle
	
	blah, blah, blah
	
	teine para
	
	.. image:: stop

Title2
-------
Kala pala `link <https://thonny.org>`_.

* essa
* tessa
* kossa

Title3
~~~~~~~~~~~